=====
Kylie
=====

.. image:: https://img.shields.io/travis/judy2k/kylie.svg
        :target: https://travis-ci.org/judy2k/kylie

.. image:: https://img.shields.io/pypi/v/kylie.svg
        :target: https://pypi.python.org/pypi/kylie


Kylie provides mappings between JSON data structures and Python objects.

* Free software: BSD license
* Documentation: https://kylie.readthedocs.org.

Features
--------

* Allows properties to have different names between Models and python dictionary keys.
* Allows type conversion when serializing and deserializing objects.
* Automatic serialization/deserialization of attributes that are also Models.
